Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1735)

Unified Diff: chrome/browser/io_thread.cc

Issue 5384002: net: Remove typedef net::URLRequest URLRequest; (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: review Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/io_thread.cc
diff --git a/chrome/browser/io_thread.cc b/chrome/browser/io_thread.cc
index 1067bf8f5a5b8893cd372715614b69fa4cec1ba2..94d31262f4e91c278c58d628b60854270b6a55ff 100644
--- a/chrome/browser/io_thread.cc
+++ b/chrome/browser/io_thread.cc
@@ -343,7 +343,7 @@ void IOThread::Init() {
void IOThread::CleanUp() {
// Step 1: Kill all things that might be holding onto
- // URLRequest/URLRequestContexts.
+ // net::URLRequest/URLRequestContexts.
#if defined(USE_NSS)
net::ShutdownOCSP();
@@ -437,12 +437,12 @@ void IOThread::CleanUpAfterMessageLoopDestruction() {
// anything else can reference it.
BrowserProcessSubThread::CleanUpAfterMessageLoopDestruction();
// URLRequest instances must NOT outlive the IO thread.
//
// To allow for URLRequests to be deleted from
// MessageLoop::DestructionObserver this check has to happen after CleanUp
// (which runs before DestructionObservers).
- base::debug::LeakTracker<URLRequest>::CheckForLeaks();
+ base::debug::LeakTracker<net::URLRequest>::CheckForLeaks();
}
// static
@@ -437,12 +437,12 @@ void IOThread::CleanUpAfterMessageLoopDestruction() {
// anything else can reference it.
BrowserProcessSubThread::CleanUpAfterMessageLoopDestruction();
- // URLRequest instances must NOT outlive the IO thread.
+ // net::URLRequest instances must NOT outlive the IO thread.
//
// To allow for URLRequests to be deleted from

Powered by Google App Engine
This is Rietveld 408576698